@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014-2016 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2014-2017 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -32,6 +32,7 @@
 #include "as-enums.h"
 #include "as-format.h"
 #include "as-icon.h"
+#include "as-launchable.h"
 #include "as-provide.h"
 #include "as-release.h"
 #include "as-screenshot.h"
@@ -126,6 +127,7 @@ typedef enum {
  * @AS_APP_SUBSUME_FLAG_PROJECT_LICENSE: Copy the project license
  * @AS_APP_SUBSUME_FLAG_PROJECT_GROUP:	Copy the project group
  * @AS_APP_SUBSUME_FLAG_SOURCE_KIND:	Copy the source kind
+ * @AS_APP_SUBSUME_FLAG_LAUNCHABLES:	Copy the launchables
  *
  * The flags to use when subsuming applications.
  **/
@@ -167,6 +169,7 @@ typedef enum {
 	AS_APP_SUBSUME_FLAG_PROJECT_GROUP	= 1ull << 33,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_SOURCE_KIND		= 1ull << 34,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_SUGGESTS		= 1ull << 35,	/* Since: 0.6.3 */
+	AS_APP_SUBSUME_FLAG_LAUNCHABLES		= 1ull << 36,	/* Since: 0.6.13 */
 	/*< private >*/
 	AS_APP_SUBSUME_FLAG_LAST,
 } AsAppSubsumeFlags;
@@ -198,6 +201,7 @@ typedef enum {
 					 AS_APP_SUBSUME_FLAG_SUGGESTS | \
 					 AS_APP_SUBSUME_FLAG_TRANSLATIONS | \
 					 AS_APP_SUBSUME_FLAG_SOURCE_KIND | \
+					 AS_APP_SUBSUME_FLAG_LAUNCHABLES | \
 					 AS_APP_SUBSUME_FLAG_URL)
 
 /* deprecated name */
@@ -442,6 +446,7 @@ typedef enum {
  * @AS_APP_SEARCH_MATCH_NAME:			Use the app name
  * @AS_APP_SEARCH_MATCH_KEYWORD:		Use the app keyword
  * @AS_APP_SEARCH_MATCH_ID:			Use the app application ID
+ * @AS_APP_SEARCH_MATCH_ORIGIN:			Use the app origin
  *
  * The token match kind, which we want to be exactly 16 bits for storage
  * reasons.
@@ -455,6 +460,7 @@ typedef enum __attribute__((__packed__)) {
 	AS_APP_SEARCH_MATCH_NAME	= 1 << 4,	/* Since: 0.6.5 */
 	AS_APP_SEARCH_MATCH_KEYWORD	= 1 << 5,	/* Since: 0.6.5 */
 	AS_APP_SEARCH_MATCH_ID		= 1 << 6,	/* Since: 0.6.5 */
+	AS_APP_SEARCH_MATCH_ORIGIN	= 1 << 7,	/* Since: 0.6.13 */
 	/*< private >*/
 	AS_APP_SEARCH_MATCH_LAST	= 0xffff
 } AsAppSearchMatch;
@@ -477,6 +483,7 @@ AsAppScope	 as_app_get_scope		(AsApp		*app);
 AsAppMergeKind	 as_app_get_merge_kind		(AsApp		*app);
 AsAppState	 as_app_get_state		(AsApp		*app);
 AsAppTrustFlags	 as_app_get_trust_flags		(AsApp		*app);
+AsAppSearchMatch as_app_get_search_match	(AsApp		*app);
 GList		*as_app_get_languages		(AsApp		*app);
 GPtrArray	*as_app_get_addons		(AsApp		*app);
 GPtrArray	*as_app_get_categories		(AsApp		*app);
@@ -492,6 +499,7 @@ GPtrArray	*as_app_get_pkgnames		(AsApp		*app);
 GPtrArray	*as_app_get_architectures	(AsApp		*app);
 GPtrArray	*as_app_get_releases		(AsApp		*app);
 GPtrArray	*as_app_get_provides		(AsApp		*app);
+GPtrArray	*as_app_get_launchables		(AsApp		*app);
 GPtrArray	*as_app_get_screenshots		(AsApp		*app);
 GPtrArray	*as_app_get_reviews		(AsApp		*app);
 GPtrArray	*as_app_get_content_ratings	(AsApp		*app);
@@ -552,6 +560,9 @@ gboolean	 as_app_has_compulsory_for_desktop (AsApp	*app,
 						 const gchar	*desktop);
 gboolean	 as_app_has_quirk		(AsApp		*app,
 						 AsAppQuirk	 quirk);
+AsLaunchable	*as_app_get_launchable_default	(AsApp		*app);
+AsLaunchable	*as_app_get_launchable_by_kind	(AsApp		*app,
+						 AsLaunchableKind kind);
 
 /* setters */
 void		 as_app_set_id			(AsApp		*app,
@@ -566,6 +577,8 @@ void		 as_app_set_state		(AsApp		*app,
 						 AsAppState	 state);
 void		 as_app_set_trust_flags		(AsApp		*app,
 						 AsAppTrustFlags trust_flags);
+void		 as_app_set_search_match	(AsApp		*app,
+						 AsAppSearchMatch search_match);
 void		 as_app_set_origin		(AsApp		*app,
 						 const gchar	*origin);
 void		 as_app_set_project_group	(AsApp		*app,
@@ -598,11 +611,15 @@ void		 as_app_set_priority		(AsApp		*app,
 						 gint		 priority);
 void		 as_app_add_category		(AsApp		*app,
 						 const gchar	*category);
+void		 as_app_remove_category		(AsApp		*app,
+						 const gchar	*category);
 void		 as_app_add_keyword		(AsApp		*app,
 						 const gchar	*locale,
 						 const gchar	*keyword);
 void		 as_app_add_kudo		(AsApp		*app,
 						 const gchar	*kudo);
+void		 as_app_remove_kudo		(AsApp		*app,
+						 const gchar	*kudo);
 void		 as_app_add_kudo_kind		(AsApp		*app,
 						 AsKudoKind	 kudo_kind);
 void		 as_app_add_permission		(AsApp		*app,
@@ -621,6 +638,8 @@ void		 as_app_add_release		(AsApp		*app,
 						 AsRelease	*release);
 void		 as_app_add_provide		(AsApp		*app,
 						 AsProvide	*provide);
+void		 as_app_add_launchable		(AsApp		*app,
+						 AsLaunchable	*launchable);
 void		 as_app_add_screenshot		(AsApp		*app,
 						 AsScreenshot	*screenshot);
 void		 as_app_add_review		(AsApp		*app,
