@@ -124,6 +124,10 @@ gint		 as_utils_vercmp		(const gchar	*version_a,
 						 const gchar	*version_b);
 gboolean	 as_utils_guid_is_valid		(const gchar	*guid);
 gchar		*as_utils_guid_from_string	(const gchar	*str);
+gchar		*as_utils_guid_from_data	(const gchar	*namespace_id,
+						 const guint8	*data,
+						 gsize		 data_len,
+						 GError		**error);
 gchar		*as_utils_version_from_uint32	(guint32	 val,
 						 AsVersionParseFlag flags);
 gchar		*as_utils_version_from_uint16	(guint16	 val,
@@ -142,6 +146,8 @@ gboolean	 as_utils_unique_id_equal	(const gchar	*unique_id1,
 						 const gchar	*unique_id2);
 gboolean	 as_utils_unique_id_valid	(const gchar	*unique_id);
 guint		 as_utils_unique_id_hash	(const gchar	*unique_id);
+gchar		*as_utils_appstream_id_build	(const gchar	*str);
+gboolean	 as_utils_appstream_id_valid	(const gchar	*str);
 
 G_END_DECLS
 
